package urlutil

import "github.com/docker/buildx/util/urlutil"

Index

Functions

func IsHTTPURL

func IsHTTPURL(str string) bool

IsHTTPURL returns true if the provided str is an HTTP(S) URL by checking if it has a http:// or https:// scheme. No validation is performed to verify if the URL is well-formed.

func IsRemoteURL

func IsRemoteURL(c string) bool

IsRemoteURL returns true for HTTP(S) URLs and Git references.

Source Files

urlutil.go

Version
v0.33.0 (latest)
Published
Mar 31, 2026
Platform
linux/amd64
Imports
2 packages
Last checked
9 hours ago

Tools for package owners.